A11yNode class final

Annotations
  • @immutable

Constructors

A11yNode({required int id, required Widget widget, required int? parentId, required List<int> children, required String role, String? label})
const

Properties

children List<int>
Child node ids in tree order.
final
hashCode int
The hash code for this object.
no setterinherited
id int
Deterministic, stable identifier for this node.
final
label String?
Optional accessibility label for this node.
final
parentId int?
Parent node id, or null for the root.
final
role String
Accessibility role for this node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Widget
Widget represented by this node.
final

Methods

hasSameSemanticShape(A11yNode other) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited