AutocompleteItem class final

One row in an AutocompleteOverlay.

Constructors

AutocompleteItem({required String id, required String label, String? description, String? group, String? insertText, bool disabled = false})
const

Properties

description String?
final
disabled bool
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
insertText String?
Text inserted on select; defaults to label.
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textToInsert String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited