AutocompleteQuery class final

Result of scanning prompt text for an autocomplete query.

Constructors

AutocompleteQuery({required AutocompleteTrigger trigger, required int triggerIndex, required String query})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
query String
Text after the trigger (may be empty).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger AutocompleteTrigger
final
triggerIndex int
Index of @ or / in the source string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited