DebugConsoleEntry class final
One line in a DebugConsoleController.
Constructors
- DebugConsoleEntry({required String message, String level = 'info', DateTime? timestamp})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → String
-
Semantic level label such as
debug,info,warn, orerror.final - message → String
-
Console line text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Timestamp attached when the line was added.
final
- timestampLabel → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited