DiffReviewFile class final

One changed file in a DiffReviewPane.

Constructors

DiffReviewFile({required String path, required String diff, int additions = 0, int deletions = 0})
const

Properties

additions int
final
deletions int
final
diff String
Unified diff body (may include diff --git headers).
final
fileName String
no setter
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited