ReloadFileWatcher class final

Properties

controller ReloadController
no setter
debounce Duration
no setter
hashCode int
The hash code for this object.
no setterinherited
ignoreHidden bool
no setter
mode ReloadMode
no setter
pendingPaths List<String>
no setter
recursive bool
no setter
roots List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

watch({required ReloadController controller, required Iterable<String> roots, ReloadMode mode = ReloadMode.reload, Duration debounce = const Duration(milliseconds: 150), bool recursive = true, bool ignoreHidden = true, Iterable<String> extensions = const <String>[]}) Future<ReloadFileWatcher>