StatefulWidget class abstract
A widget with mutable state managed by a State object.
- Inheritance
- Implementers
- ActionButton
- AnimatedBuilder
- AnimatedTint
- BlockFocus
- Button
- ChartBuilder
- Checkbox
- ChordHost
- CodeEditor
- CommandPalette
- DebugConsole
- DebugConsoleHost
- DebugOverlay
- DialogAlert
- DialogConfirm
- DialogPrompt
- DialogSelect
- DialogStack
- DiffReviewPane
- ExpansionTile
- FadeModalBarrier
- FadeTint
- FilePicker
- Focusable
- FocusScope
- FutureBuilder
- GestureDetector
- GitDiffViewer
- Image
- ImplicitlyAnimatedWidget
- InputChip
- KeyboardListener
- KeymapHubScope
- LinearProgressIndicator
- ListenableBuilder
- ListView
- MarkdownEditor
- MarkdownText
- Navigator
- Overlay
- PerformanceOverlay
- PopupMenuButton
- Radio
- RangeSlider
- ReloadHost
- ScrollArea
- Scrollbar
- ScrollView
- SelectionArea
- ShortcutSurfaceScope
- SingleChildScrollView
- Slider
- SpinnerIndicator
- StreamBuilder
- Switch
- TextArea
- TextEditor
- TextField
- Tooltip
- ValueListenableBuilder
- Viewport
- VirtualListView
- Wizard
Constructors
- StatefulWidget({Key? key})
- Creates a stateful widget.
Properties
- accessibilityLabel → String?
-
Optional accessibility label.
no setterinherited
- accessibilityRole → String
-
Optional accessibility role.
no setterinherited
-
children
→ List<
Widget> -
Child widgets that receive forwarded messages.
no setterinherited
- debugRenderObjectPassthrough → bool
-
Whether this widget is intentionally transparent to render-object layouts.
no setterinherited
- degradationSignal → WidgetDegradationSignal
-
Signal that controls this widget's render budget behavior.
no setterinherited
- focusable → bool
-
Whether this widget can receive keyboard focus.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this widget.
no setterinherited
- key → Key?
-
Key for preserving widget identity.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → Theme
-
Access the current theme.
no setterinherited
Methods
-
buildCachedView<
T> (T builder(), Object? cacheKey) → T -
Returns a cached view if the cache key matches.
inherited
-
createState(
) → State< StatefulWidget> - Creates the mutable State associated with this widget.
-
handleInit(
) → Cmd? -
Override this instead of init for widget-specific initialization.
inherited
-
handleIntercept(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages before they reach children.
inherited
-
handleUpdate(
Msg msg) → (Widget, Cmd?) -
Override this to handle messages specific to this widget.
inherited
-
init(
) → Cmd? -
Called once when the widget is first mounted.
inherited
-
invalidateCachedView(
) → void -
Clears any cached view for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRenderAt(
DegradationLevel degradationLevel, {required bool subtreeHasFocusedWidget}) → bool -
Whether this widget should participate in the current render when
degradationLevelis active.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
update(
Msg msg) → (Model, Cmd?) -
Handles messages by forwarding to children then calling handleUpdate.
inherited
-
view(
) → Object -
Renders the widget to a string or View.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited