WidgetStormRunner class final

Runner that applies WidgetStormProfile instances to one tester.

Constructors

WidgetStormRunner(WidgetTester tester)
Creates a storm runner bound to tester.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tester WidgetTester
Tester receiving generated events.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(WidgetStormProfile profile) WidgetStormResult
Runs profile and returns a structured result.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited