toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return switch (action) {
    WidgetStormAction.key => '#$index key "$text"',
    WidgetStormAction.specialKey => '#$index specialKey ${keyType?.name}',
    WidgetStormAction.paste => '#$index paste ${text?.length ?? 0} chars',
    WidgetStormAction.mouseMove => '#$index mouseMove $x,$y',
    WidgetStormAction.tap => '#$index tap $x,$y',
    WidgetStormAction.drag =>
      '#$index drag $x,$y -> $endX,$endY steps=$dragSteps',
    WidgetStormAction.resize => '#$index resize ${width}x$height',
    WidgetStormAction.pump => '#$index pump',
  };
}