BrailleCanvas class final

A 2x4 sub-cell braille canvas for plotting terminal-native 2D graphics.

Coordinates passed to point and rect are in braille-dot space, not cell space. A canvas of width=40, height=10 has a dot-space size of 80 x 40.

Constructors

BrailleCanvas(int cellWidth, int cellHeight)

Properties

cellHeight int
final
cellWidth int
final
dotHeight int
no setter
dotWidth int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
point(int x, int y, {UvStyle style = const UvStyle()}) → void
Plot a single braille dot.
rect(int x0, int y0, int x1, int y1, {UvStyle style = const UvStyle()}) → void
Draw a rectangle outline in braille-dot space.
renderTo(Screen screen, Rectangle area, {UvStyle fallbackStyle = const UvStyle()}) → void
Render this braille canvas into screen within area.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited