sendMsg method
void
sendMsg(
- Msg msg
Sends an arbitrary Msg to the Program and captures the view.
Implementation
void sendMsg(Msg msg) {
_ensureRunning();
_program!.send(msg);
_syncView();
}
Sends an arbitrary Msg to the Program and captures the view.
void sendMsg(Msg msg) {
_ensureRunning();
_program!.send(msg);
_syncView();
}