matches method
Returns true if this binding is enabled and msg matches its keys.
Implementation
bool matches(KeyMsg msg) => enabled && keyMatches(msg.key, [this]);
Returns true if this binding is enabled and msg matches its keys.
bool matches(KeyMsg msg) => enabled && keyMatches(msg.key, [this]);