FlickerAnalyzer class final
Analyzer for synchronized-output gaps, partial clears, and broken frames.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
analyze(
String output, {String runId = 'widget-test', bool requireSynchronizedOutput = false}) → FlickerAnalysis -
Scans
outputand returns a structured analysis.