HarnessArtifactValidation class final
Validation result for one artifact entry.
Constructors
-
HarnessArtifactValidation({required HarnessArtifactClass artifactClass, required String path, required List<
String> missingFields, required bool oversize}) -
Creates an artifact validation result.
const
Properties
- artifactClass → HarnessArtifactClass
-
Artifact class.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
missingFields
→ List<
String> -
Required fields missing from the artifact payload.
final
- oversize → bool
-
Whether path exceeds the class size recommendation.
final
- passes → bool
-
Whether this entry passes validation.
no setter
- path → String
-
Relative path within a run bundle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this result into a serialization-friendly map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited