TextSpan class
Constructors
-
TextSpan({Style? style, TextStyle? textStyle, Style? selectionHighlightStyle, String? text, List<TextSpan> children = const []})
-
const
Properties
-
children
→ List<TextSpan>
-
Child spans that inherit this span's resolved presentation.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectionHighlightStyle
→ Style?
-
Style used when this span is selected.
final
-
style
→ Style?
-
Complete Artisanal style applied to this span.
final
-
text
→ String?
-
Text owned by this span.
final
-
textStyle
→ TextStyle?
-
Immutable text-only declarations applied after style.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited