WidgetFuzzResult class final
Result of a deterministic widget fuzz run.
Constructors
-
WidgetFuzzResult({required int seed, required int requestedSteps, required List<
WidgetFuzzStep> history, required List<WidgetTestFrame> frames, WidgetFuzzStep? failedStep, Object? error, StackTrace? stackTrace}) -
const
Properties
- completedSteps → int
-
Number of generated steps that completed.
no setter
- error → Object?
-
Captured error from the failed step, if any.
final
- failedStep → WidgetFuzzStep?
-
Step that failed, if any.
final
-
frames
→ List<
WidgetTestFrame> -
Frames recorded during fuzzing when frame capture was enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
→ List<
WidgetFuzzStep> -
All generated steps, including the failed step when a failure occurs.
final
- passed → bool
-
Whether the run completed without an exception.
no setter
- requestedSteps → int
-
Number of steps requested by WidgetFuzzOptions.steps.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → int
-
Seed used for the run.
final
- stackTrace → StackTrace?
-
Captured stack trace from the failed step, if any.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
throwIfFailed(
) → void - Throws WidgetFuzzFailure when passed is false.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited