WidgetGauntletConfig class final
Configuration for WidgetGauntlet.
Constructors
-
WidgetGauntletConfig({String runId = 'widget-gauntlet', String runtimeLane = 'widget-test', List<
WidgetStormProfile> stormProfiles = const <WidgetStormProfile>[], bool analyzeFlicker = false, bool requireSynchronizedOutput = false, DateTime nowProvider()?}) -
Creates a gauntlet configuration.
const
Properties
- analyzeFlicker → bool
-
Whether to analyze raw terminal writes after the run.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nowProvider → DateTime Function()?
-
Clock seam for deterministic tests.
final
- requireSynchronizedOutput → bool
-
Whether visible output outside synchronized brackets is an error.
final
- runId → String
-
Run identifier used in reports and artifact manifests.
final
- runtimeLane → String
-
Runtime lane label for reports.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stormProfiles
→ List<
WidgetStormProfile> -
Storm profiles to run after the widget is mounted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited