WidgetStormStep class final
One generated storm action.
Constructors
Properties
- action → WidgetStormAction
-
Action family.
final
- dragSteps → int?
-
Drag motion steps.
final
- endX → int?
-
Drag destination x coordinate.
final
- endY → int?
-
Drag destination y coordinate.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Resize target height.
final
- index → int
-
Zero-based index in the generated storm.
final
- keyType → KeyType?
-
Special key payload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Text payload for key and paste actions.
final
- width → int?
-
Resize target width.
final
- x → int?
-
Primary x coordinate for pointer actions.
final
- y → int?
-
Primary y coordinate for pointer actions.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this step into a serialization-friendly map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited