textLocation method
Returns a TapTarget that locates text in the rendered output and
taps at its coordinates.
This is the preferred way to tap widgets when using hit-test dispatch.
tester.tap(tester.find.textLocation('Submit'));
Implementation
TapTarget textLocation(String text) => _TextTapTarget(text);